==> crud_service-0.1.6.tar.gz: lib/Model/RequestFilter.dart <==

enum CRUDOperator {
  EQUALS,   // 等于
  NE,       // 不等于
  GT,       // 大于
  LT,       // 小于
  GTE,      // 大于等于
  LTE,      // 小于等于
  BETWEEN,  // 区间
  LIKE,     // 模糊匹配
  IN,       // 包含
  NOTIN,    // 不包含
  ISNULL,
  NOTNULL,
  NOTNULL22,
  ALLOF
}

class RequestFilter<T> {

  CRUDOperator operator;

  String field;

  T value;

  T value_to;

  RequestFilter(this.operator, this.field, this.value, {this.value_to});

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["operator"] = operatorDesc();
    data["field"] = field;
    if (value != null) {
      data["value"] = value;
    }
    if (value_to != null) {
      data["value_to"] = value_to;
    }
    return data;
  }

  String operatorDesc() {
    switch (operator) {
      case CRUDOperator.EQUALS:
        return "EQUALS";
      case CRUDOperator.NE:
        return "NE";
      case CRUDOperator.GT:
        return "GT";
      case CRUDOperator.LT:
        return "LT";
      case CRUDOperator.GTE:
        return "GTE";
      case CRUDOperator.LTE:
        return "LTE";
      case CRUDOperator.BETWEEN:
        return "BETWEEN";
      case CRUDOperator.LIKE:
        return "LIKE";
      case CRUDOperator.IN:
        return "IN";
      case CRUDOperator.NOTIN:
        return "NOTIN";
      case CRUDOperator.ISNULL:
        return "ISNULL";
      case CRUDOperator.NOTNULL:
        return "NOTNULL";
      case CRUDOperator.NOTNULL22:
        return "NOTNULL22";
      case CRUDOperator.ALLOF:
        return "ALLOF";
    }
  }
}

==> crud_service-0.1.9.tar.gz: lib/Model/RequestFilter.dart <==

enum CRUDOperator {
  EQUALS,   // 等于
  NE,       // 不等于
  GT,       // 大于
  LT,       // 小于
  GTE,      // 大于等于
  LTE,      // 小于等于
  BETWEEN,  // 区间
  LIKE,     // 模糊匹配
  IN,       // 包含
  NOTIN,    // 不包含
  ISNULL,
  NOTNULL,
  NOTNULL22,
  ALLOF
}

class RequestFilter<T> {

  CRUDOperator operator;

  String field;

  T value;

  T value_to;

  RequestFilter(this.operator, this.field, this.value, {this.value_to});

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["operator"] = operatorDesc();
    data["field"] = field;
 	  if (value != null) {
      switch (operator) {
        case CRUDOperator.IN:
        case CRUDOperator.NOTIN:
          data["values"] = value;
          break;
        default:
          data["value"] = value;;
          break;
      }
    }
    if (value_to != null) {
      data["value_to"] = value_to;
    }
    return data;
  }

  String operatorDesc() {
    switch (operator) {
      case CRUDOperator.EQUALS:
        return "EQUALS";
      case CRUDOperator.NE:
        return "NE";
      case CRUDOperator.GT:
        return "GT";
      case CRUDOperator.LT:
        return "LT";
      case CRUDOperator.GTE:
        return "GTE";
      case CRUDOperator.LTE:
        return "LTE";
      case CRUDOperator.BETWEEN:
        return "BETWEEN";
      case CRUDOperator.LIKE:
        return "LIKE";
      case CRUDOperator.IN:
        return "IN";
      case CRUDOperator.NOTIN:
        return "NOTIN";
      case CRUDOperator.ISNULL:
        return "ISNULL";
      case CRUDOperator.NOTNULL:
        return "NOTNULL";
      case CRUDOperator.NOTNULL22:
        return "NOTNULL22";
      case CRUDOperator.ALLOF:
        return "ALLOF";
    }
  }
}
